==> mingw-w64-notepad%2B%2B-8.7.5-1.src.tar.zst: notepad-plus-plus-8.7.5/PowerEditor/src/ScintillaComponent/columnEditor_rc.h <==
// This file is part of Notepad++ project
// Copyright (C)2021 Don HO <don.h@free.fr>

// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// at your option any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <https://www.gnu.org/licenses/>.


#ifndef COLUMNEDITOR_RC_H
#define COLUMNEDITOR_RC_H

#define	IDD_COLUMNEDIT   2020
	#define	IDC_COL_INITNUM_EDIT		(IDD_COLUMNEDIT + 1)
	#define	IDC_COL_INCREASENUM_EDIT	(IDD_COLUMNEDIT + 2)
	#define	IDC_COL_TEXT_RADIO			(IDD_COLUMNEDIT + 3)
	#define	IDC_COL_DEC_RADIO			(IDD_COLUMNEDIT + 4)
	#define	IDC_COL_OCT_RADIO			(IDD_COLUMNEDIT + 5)
	#define	IDC_COL_HEX_RADIO			(IDD_COLUMNEDIT + 6)
	#define	IDC_COL_BIN_RADIO			(IDD_COLUMNEDIT + 7)
	#define	IDC_COL_TEXT_GRP_STATIC		(IDD_COLUMNEDIT + 8)
	#define	IDC_COL_NUM_GRP_STATIC		(IDD_COLUMNEDIT + 9)
	#define	IDC_COL_INITNUM_STATIC		(IDD_COLUMNEDIT + 10)
	#define	IDC_COL_INCRNUM_STATIC		(IDD_COLUMNEDIT + 11)
	#define	IDC_COL_FORMAT_GRP_STATIC	(IDD_COLUMNEDIT + 12)
	#define	IDC_COL_NUM_RADIO			(IDD_COLUMNEDIT + 13)
	#define	IDC_COL_TEXT_EDIT			(IDD_COLUMNEDIT + 14)
	#define IDC_COL_REPEATNUM_STATIC	(IDD_COLUMNEDIT + 16)
	#define IDC_COL_REPEATNUM_EDIT		(IDD_COLUMNEDIT + 17)
	#define	IDC_COL_LEADING_STATIC		(IDD_COLUMNEDIT + 18)
	#define IDC_COL_LEADING_COMBO		(IDD_COLUMNEDIT + 19)
#endif// COLUMNEDITOR_RC_H

==> mingw-w64-notepad%2B%2B-8.8.9-1.src.tar.zst: notepad-plus-plus-8.8.9/PowerEditor/src/ScintillaComponent/columnEditor_rc.h <==
// This file is part of Notepad++ project
// Copyright (C)2021 Don HO <don.h@free.fr>

// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// at your option any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <https://www.gnu.org/licenses/>.


#ifndef COLUMNEDITOR_RC_H
#define COLUMNEDITOR_RC_H

#define	IDD_COLUMNEDIT   2020
	#define	IDC_COL_INITNUM_EDIT		(IDD_COLUMNEDIT + 1)
	#define	IDC_COL_INCREASENUM_EDIT	(IDD_COLUMNEDIT + 2)
	#define	IDC_COL_TEXT_RADIO			(IDD_COLUMNEDIT + 3)
	#define	IDC_COL_DEC_RADIO			(IDD_COLUMNEDIT + 4)
	#define	IDC_COL_OCT_RADIO			(IDD_COLUMNEDIT + 5)
	#define	IDC_COL_HEX_RADIO			(IDD_COLUMNEDIT + 6)
	#define	IDC_COL_BIN_RADIO			(IDD_COLUMNEDIT + 7)
	#define	IDC_COL_TEXT_GRP_STATIC		(IDD_COLUMNEDIT + 8)
	#define	IDC_COL_NUM_GRP_STATIC		(IDD_COLUMNEDIT + 9)
	#define	IDC_COL_INITNUM_STATIC		(IDD_COLUMNEDIT + 10)
	#define	IDC_COL_INCRNUM_STATIC		(IDD_COLUMNEDIT + 11)
	#define	IDC_COL_FORMAT_GRP_STATIC	(IDD_COLUMNEDIT + 12)
	#define	IDC_COL_NUM_RADIO			(IDD_COLUMNEDIT + 13)
	#define	IDC_COL_TEXT_EDIT			(IDD_COLUMNEDIT + 14)
	#define IDC_COL_REPEATNUM_STATIC	(IDD_COLUMNEDIT + 16)
	#define IDC_COL_REPEATNUM_EDIT		(IDD_COLUMNEDIT + 17)
	#define	IDC_COL_LEADING_STATIC		(IDD_COLUMNEDIT + 18)
	#define IDC_COL_LEADING_COMBO		(IDD_COLUMNEDIT + 19)
	#define IDC_COL_HEXUC_COMBO			(IDD_COLUMNEDIT + 20)
	#define	IDT_COL_FLASH_TIMER			(IDD_COLUMNEDIT + 21)
	#define	IDC_COL_BALLONTIP_TIMER		(IDD_COLUMNEDIT + 22)
#endif// COLUMNEDITOR_RC_H
